<?xml version="1.0"?>
<xsl:stylesheet version="1.0" 
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns:user="http://www.kjetil.kjernsmo.net/software/TABOO/NS/User/Output"
  xmlns:art="http://www.kjetil.kjernsmo.net/software/TABOO/NS/Article/Output"
  xmlns:cat="http://www.kjetil.kjernsmo.net/software/TABOO/NS/Category/Output"
  xmlns:comm="http://www.kjetil.kjernsmo.net/software/TABOO/NS/Comment/Output"
  xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#"
  xmlns:wn="http://xmlns.com/wordnet/1.6/"      
  xmlns:html="http://www.w3.org/1999/xhtml"
  xmlns:dc="http://purl.org/dc/elements/1.1/"
  xmlns:i18n="http://www.kjetil.kjernsmo.net/software/TABOO/NS/I18N"
  xmlns:texts="http://www.kjetil.kjernsmo.net/software/TABOO/NS/I18N/Texts"
  xmlns:office="http://openoffice.org/2000/office" 
  exclude-result-prefixes="office user comm art rdf wn dc i18n texts html"> 


  <xsl:import href="/transforms/xhtml/header.xsl"/>
  <xsl:import href="/transforms/news/xhtml/match-user.xsl"/>
  <xsl:import href="/transforms/xhtml/footer.xsl"/>
  <xsl:import href="/transforms/insert-i18n.xsl"/>
  <xsl:import href="oo2html.xsl"/>
  <xsl:import href="/transforms/news/xhtml/match-breadcrumbs.xsl"/>

  <xsl:output version="1.0" encoding="utf-8" indent="yes"
    method="html" media-type="text/html" 
    doctype-public="-//W3C//DTD HTML 4.01//EN" 
    doctype-system="http://www.w3.org/TR/html4/strict.dtd"/>  

  <xsl:param name="request.headers.host"/>
  <xsl:param name="request.uri"/>
  <xsl:param name="session.id"/>
  <xsl:param name="neg.lang">en</xsl:param>

  <xsl:template match="/taboo/taboo">
    <html lang="{$neg.lang}">
      <head>
	<title>
	  <xsl:value-of select="art:article/art:title"/>
	  
	  <xsl:text> | </xsl:text>
	  <xsl:value-of select="document('/site/main.rdf')//dc:title/rdf:Alt/rdf:_2"/>
	</title>
	<xsl:call-template name="CommonHTMLHead"/>
	<link rel="top" href="/"/>
      </head>
      <body>
	<xsl:call-template name="CreateHeader"/>
	<div id="breadcrumb">
	  <xsl:call-template name="BreadcrumbTop"/>
	</div>
	<div id="container">
	  <xsl:variable name="uri" select="concat('http://',
	    $request.headers.host, '/menu.xsp?SID=' , $session.id)"/>
	  <xsl:copy-of select="document($uri)"/>
	  <div class="main">

	    <h2 id="byline">
	      <xsl:for-each select="art:article/user:author">
		<span class="authorname">  
		  <a>
		    <xsl:attribute name="href">
		      <xsl:text>/user/</xsl:text><xsl:value-of
		      select="./user:username"/>
		    </xsl:attribute>
		    <xsl:value-of select="./user:name" />
		  </a>
		</span>
		<xsl:choose>
		  <xsl:when test="position()=last()">
		    <xsl:text>:</xsl:text>
		  </xsl:when>
		  <xsl:when test="position()=last()-1">
		    <xsl:value-of select="i18n:include('and')"/>
		  </xsl:when>
		  <xsl:otherwise>
		    <xsl:text>, </xsl:text>
		  </xsl:otherwise>
		</xsl:choose>
	      </xsl:for-each>
	    </h2>

	    <xsl:variable name="content" select="document(@contenturl)"/>
	   
	    <div id="content">
	      <xsl:choose>
		<xsl:when test="art:article/art:format = 'application/xhtml+xml'">
		  <xsl:if test="not($content/html:html/html:body/html:h1)">
		    <h1><xsl:value-of select="art:article/art:title"/></h1>
		  </xsl:if>
		  <xsl:copy-of select="$content/html:html/html:body/child::*"/>
		</xsl:when>
		<xsl:when test="art:article/art:format = 'application/vnd.sun.xml.writer'">
		  <xsl:apply-templates select="$content/office:document-content/office:body"/>
		</xsl:when>
		<xsl:when test="not($content/html/body)">
		   <xsl:copy-of select="$content"/>
		</xsl:when>
		<xsl:otherwise>
		  <xsl:if test="not($content/html/body/h1)">
		    <h1><xsl:value-of select="art:article/art:title"/></h1>
		  </xsl:if>
		  <xsl:copy-of select="$content/html/body/child::*"/>
		</xsl:otherwise>
	      </xsl:choose>
	    </div>

	  </div>
	</div>
	<xsl:call-template name="CreateFooter"/>

      </body>
    </html>
  </xsl:template>


</xsl:stylesheet>